The summary() method for objects of class simsum returns confidence intervals for performance measures based on Monte Carlo standard errors.
# S3 method for simsum
summary(object, ci_level = 0.95, df = NULL, stats = NULL, ...)An object of class summary.simsum.
An object of class simsum.
Significance level for confidence intervals based on Monte Carlo standard errors. Ignored if a simsum object with control parameter mcse = FALSE is passed.
Degrees of freedom of a t distribution that will be used to calculate confidence intervals based on Monte Carlo standard errors. If NULL (the default), quantiles of a Normal distribution will be used instead. However, using Z-based or t-based confidence intervals is valid only for summary statistics such a bias and coverage. Confidence intervals for other quantities may not be appropriate, therefore their usage is not recommended.
Summary statistics to include; can be a scalar value or a vector (for multiple summary statistics at once). Possible choices are:
nsim, the number of replications with non-missing point estimates and standard error.
thetamean, average point estimate.
thetamedian, median point estimate.
se2mean, average variance.
se2median, median variance.
bias, bias in point estimate.
rbias, relative (to the true value) bias in point estimate.
empse, empirical standard error.
mse, mean squared error.
relprec, percentage gain in precision relative to the reference method.
modelse, model-based standard error.
relerror, relative percentage error in standard error.
cover, coverage of a nominal level\
becover, bias corrected coverage of a nominal level\
power, power of a (1 - level)\
Defaults to NULL, in which case all possible summary statistics are included.
Ignored.
simsum(), print.summary.simsum()
data("MIsim")
object <- simsum(
data = MIsim, estvarname = "b", true = 0.5, se = "se",
methodvar = "method"
)
xs <- summary(object)
xs
Run the code above in your browser using DataLab